@@ -235,10 +235,16 @@ class Work(sequence_ordered(), ModelSQL, ModelView):
             ('production.rec_name',) + tuple(clause[1:]),
             ]
 
+    @classmethod
+    def create(cls, values):
+        works = super(Work, cls).create(values)
+        cls.set_state(works)
+        return works
+
     @classmethod
     def delete(cls, works):
         for work in works:
-            if work.state != 'request':
+            if work.state not in {'request', 'draft'}:
                 cls.raise_user_error('delete_request', work.rec_name)
         super(Work, cls).delete(works)
 
